@@ -184,6 +184,10 @@ struct flb_output_plugin {
     struct mk_list _head;
 };
 
+// constants for retry_limit
+#define FLB_OUT_RETRY_UNLIMITED -1
+#define FLB_OUT_RETRY_NONE       0
+
 /*
  * Each initialized plugin must have an instance, same plugin may be
  * loaded more than one time.
@@ -645,9 +649,11 @@ static inline int flb_output_config_map_set(struct flb_output_instance *ins,
     int ret;
 
     /* Process normal properties */
-    ret = flb_config_map_set(&ins->properties, ins->config_map, context);
-    if (ret == -1) {
-        return -1;
+    if (ins->config_map) {
+        ret = flb_config_map_set(&ins->properties, ins->config_map, context);
+        if (ret == -1) {
+            return -1;
+        }
     }
 
     /* Net properties */
