@@ -23,12 +23,14 @@
 
 #define FLB_SPLUNK_DEFAULT_HOST       "127.0.0.1"
 #define FLB_SPLUNK_DEFAULT_PORT       8088
-#define FLB_SPLUNK_DEFAULT_URI        "/services/collector/event"
+#define FLB_SPLUNK_DEFAULT_URI_RAW    "/services/collector/raw"
+#define FLB_SPLUNK_DEFAULT_URI_EVENT  "/services/collector/event"
 #define FLB_SPLUNK_DEFAULT_TIME       "time"
 #define FLB_SPLUNK_DEFAULT_EVENT      "event"
 
 #include <fluent-bit/flb_output_plugin.h>
 #include <fluent-bit/flb_sds.h>
+#include <fluent-bit/flb_record_accessor.h>
 
 struct flb_splunk {
     /* Payload compression */
@@ -38,6 +40,10 @@ struct flb_splunk {
     char *http_user;
     char *http_passwd;
 
+    /* Single value key */
+    flb_sds_t event_key;
+    struct flb_record_accessor *ra_event_key;
+
     /* Token Auth */
     flb_sds_t auth_header;
 
