@@ -2095,6 +2095,9 @@ static void cb_stackdriver_flush(const void *data, size_t bytes,
     /* Get upstream connection */
     u_conn = flb_upstream_conn_get(ctx->u);
     if (!u_conn) {
+#ifdef FLB_HAVE_METRICS
+        flb_metrics_sum(FLB_STACKDRIVER_FAILED_REQUESTS, 1, ctx->ins->metrics);
+#endif
         FLB_OUTPUT_RETURN(FLB_RETRY);
     }
 
@@ -2105,6 +2108,9 @@ static void cb_stackdriver_flush(const void *data, size_t bytes,
                              data, bytes,
                              &out_buf, &out_size);
     if (ret != 0) {
+#ifdef FLB_HAVE_METRICS
+        flb_metrics_sum(FLB_STACKDRIVER_FAILED_REQUESTS, 1, ctx->ins->metrics);
+#endif
         flb_upstream_conn_release(u_conn);
         FLB_OUTPUT_RETURN(FLB_RETRY);
     }
@@ -2118,6 +2124,9 @@ static void cb_stackdriver_flush(const void *data, size_t bytes,
         flb_plg_error(ctx->ins, "cannot retrieve oauth2 token");
         flb_upstream_conn_release(u_conn);
         flb_sds_destroy(payload_buf);
+#ifdef FLB_HAVE_METRICS
+        flb_metrics_sum(FLB_STACKDRIVER_FAILED_REQUESTS, 1, ctx->ins->metrics);
+#endif
         FLB_OUTPUT_RETURN(FLB_RETRY);
     }
 
@@ -2170,6 +2179,16 @@ static void cb_stackdriver_flush(const void *data, size_t bytes,
         }
     }
 
+    /* Update specific stackdriver metrics */
+#ifdef FLB_HAVE_METRICS
+    if (ret_code == FLB_OK) {
+        flb_metrics_sum(FLB_STACKDRIVER_SUCCESSFUL_REQUESTS, 1, ctx->ins->metrics);
+    }
+    else {
+        flb_metrics_sum(FLB_STACKDRIVER_FAILED_REQUESTS, 1, ctx->ins->metrics);
+    }
+#endif
+
     /* Cleanup */
     flb_sds_destroy(payload_buf);
     flb_sds_destroy(token);
