@@ -60,6 +60,7 @@ struct flb_hash *flb_hash_create(int evict_mode, size_t size, int max_entries)
     ht->max_entries = max_entries;
     ht->size = size;
     ht->total_count = 0;
+    ht->cache_ttl = 0;
     ht->table = flb_calloc(1, sizeof(struct flb_hash_table) * size);
     if (!ht->table) {
         flb_errno();
@@ -77,6 +78,22 @@ struct flb_hash *flb_hash_create(int evict_mode, size_t size, int max_entries)
     return ht;
 }
 
+struct flb_hash *flb_hash_create_with_ttl(int cache_ttl, int evict_mode, 
+                                          size_t size, int max_entries)
+{
+    struct flb_hash *ht;
+
+    ht = flb_hash_create(evict_mode, size, max_entries);
+    if (!ht) {
+        flb_errno();
+        return NULL;
+    }
+
+    ht->cache_ttl = cache_ttl;
+
+    return ht;
+}
+
 int flb_hash_del_ptr(struct flb_hash *ht, const char *key, int key_len,
                      void *ptr)
 {
@@ -270,6 +287,8 @@ static int entry_set_value(struct flb_hash_entry *entry, void *val, size_t val_s
         entry->val_size = -1;
     }
 
+    entry->created = time(NULL);
+
     return 0;
 }
 
@@ -368,12 +387,21 @@ int flb_hash_get(struct flb_hash *ht,
 {
     int id;
     struct flb_hash_entry *entry;
+    time_t expiration;
 
     entry = hash_get_entry(ht, key, key_len, &id);
     if (!entry) {
         return -1;
     }
 
+    if (ht->cache_ttl > 0) {
+        expiration = entry->created + ht->cache_ttl;
+        if (time(NULL) > expiration) {
+            flb_hash_entry_free(ht, entry);
+            return -1;
+        }
+    }
+
     entry->hits++;
     *out_buf = entry->val;
     *out_size = entry->val_size;
